@@ -1,11 +1,11 @@
-/* apng2gif version 1.4
+/* apng2gif version 1.5
  *
  * This program converts APNG animations into animated GIF format.
  * Wu64 quantizer is used for true-color files.
  *
  * http://apng2gif.sourceforge.net/
  *
- * Copyright (c) 2010-2011 Max Stepin
+ * Copyright (c) 2010-2012 Max Stepin
  * maxst at users.sourceforge.net
  *
  * zlib license
@@ -320,13 +320,12 @@ void compose3(unsigned char * dst1, unsigned int dstbytes1, unsigned char * dst2
 
     for (i=0; i<w; i++)
     {
-      col = sp[i];
-
       switch (depth)
       {
-        case 4: col = (sp[i>>1] & mask4[i&1]) >> shift4[i&1]; break;
-        case 2: col = (sp[i>>2] & mask2[i&3]) >> shift2[i&3]; break;
         case 1: col = (sp[i>>3] & mask1[i&7]) >> shift1[i&7]; break;
+        case 2: col = (sp[i>>2] & mask2[i&3]) >> shift2[i&3]; break;
+        case 4: col = (sp[i>>1] & mask4[i&1]) >> shift4[i&1]; break;
+        default: col = sp[i];
       }
 
       r = pal[col][0];
@@ -1600,10 +1599,10 @@ int EncodeLZW(unsigned char * data, int datasize, FILE * f1, unsigned char minco
 
 int SaveAGIF(char * szOut, unsigned char * pimg, unsigned short * pdelays, int w, int h, int frames, int loops)
 {
-  unsigned char gif_head[13] = {0x47, 0x49, 0x46, 0x38, 0x39, 0x61, w&0xFF, w>>8, h&0xFF, h>>8, 0, (trns_idx >= 0) ? trns_idx : 0, 0};
-  unsigned char netscape[19] = {0x21, 0xFF, 0x0B, 'N', 'E', 'T', 'S', 'C', 'A', 'P', 'E', '2', '.', '0', 3, 1, loops&0xFF, loops>>8, 0};
+  unsigned char gif_head[13] = {'G', 'I', 'F', '8', '9', 'a', w&0xFF, (w>>8)&0xFF, h&0xFF, (h>>8)&0xFF, 0, (trns_idx >= 0) ? trns_idx : 0, 0};
+  unsigned char netscape[19] = {0x21, 0xFF, 0x0B, 'N', 'E', 'T', 'S', 'C', 'A', 'P', 'E', '2', '.', '0', 3, 1, loops&0xFF, (loops>>8)&0xFF, 0};
   unsigned char gce[8]       = {0x21, 0xF9, 4, 4, 10, 0, (trns_idx >= 0) ? trns_idx : 0, 0};
-  unsigned char img_head[10] = {0x2C, 0, 0, 0, 0, w&0xFF, w>>8, h&0xFF, h>>8, 0};
+  unsigned char img_head[10] = {0x2C, 0, 0, 0, 0, w&0xFF, (w>>8)&0xFF, h&0xFF, (h>>8)&0xFF, 0};
   unsigned char bits = 7;
   unsigned char end = 0x3B;
   unsigned char trns_bit = (trns_idx >= 0) ? 1 : 0;
@@ -1724,13 +1723,13 @@ int SaveAGIF(char * szOut, unsigned char * pimg, unsigned short * pdelays, int w
       gce[4] = pdelays[n]&0xFF;
       gce[5] = pdelays[n]>>8;
       img_head[1] = x0&0xFF;
-      img_head[2] = x0>>8;
+      img_head[2] = (x0>>8)&0xFF;
       img_head[3] = y0&0xFF;
-      img_head[4] = y0>>8;
+      img_head[4] = (y0>>8)&0xFF;
       img_head[5] = w0&0xFF;
-      img_head[6] = w0>>8;
+      img_head[6] = (w0>>8)&0xFF;
       img_head[7] = h0&0xFF;
-      img_head[8] = h0>>8;
+      img_head[8] = (h0>>8)&0xFF;
 
       if (fwrite(gce, 1, 8, f1) != 8) break;
       if (fwrite(img_head, 1, 10, f1) != 10) break;
@@ -1800,7 +1799,7 @@ int main(int argc, char** argv)
   unsigned short * pDelays = NULL;
   int              i, w, h, coltype, frames, loops;
 
-  printf("\napng2gif 1.4\n\n");
+  printf("\napng2gif 1.5\n\n");
 
   if (argc <= 1)
   {
